--- /dev/null	Sat May 10 12:10:18 2014
+++ new/usr/src/man/man3m/remquo.3m	Sat May 10 12:10:18 2014
@@ -0,0 +1,105 @@
+'\" te
+.\" Copyright (c) 2001, the Institute of Electrical and Electronics Engineers, Inc. and The Open Group. All Rights Reserved.
+.\" Portions Copyright (c) 2006, Sun Microsystems, Inc. All Rights Reserved.
+.\" Sun Microsystems, Inc. gratefully acknowledges The Open Group for permission to reproduce portions of its copyrighted documentation. Original documentation from The Open Group can be obtained online at 
+.\" http://www.opengroup.org/bookstore/.
+.\" The Institute of Electrical and Electronics Engineers and The Open Group, have given us permission to reprint portions of their documentation. In the following statement, the phrase "this text" refers to portions of the system documentation. Portions of this text are reprinted and reproduced in electronic form in the Sun OS Reference Manual, from IEEE Std 1003.1, 2004 Edition, Standard for Information Technology -- Portable Operating System Interface (POSIX), The Open Group Base Specifications Issue 6, Copyright (C) 2001-2004 by the Institute of Electrical and Electronics Engineers, Inc and The Open Group. In the event of any discrepancy between these versions and the original IEEE and The Open Group Standard, the original IEEE and The Open Group Standard is the referee document. The original Standard can be obtained online at http://www.opengroup.org/unix/online.html.
+.\"  This notice shall appear on any product containing this material.
+.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
+.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
+.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
+.TH remquo 3M "12 Jul 2006" "SunOS 5.11" "Mathematical Library Functions"
+.SH NAME
+remquo, remquof, remquol \- remainder functions
+.SH SYNOPSIS
+.LP
+.nf
+c99 [ \fIflag\fR... ] \fIfile\fR... \fB-lm\fR [ \fIlibrary\fR... ]
+#include <math.h>
+
+\fBdouble\fR \fBremquo\fR(\fBdouble\fR \fIx\fR, \fBdouble\fR \fIy\fR, \fBint *\fR\fIquo\fR);
+.fi
+
+.LP
+.nf
+\fBfloat\fR \fBremquof\fR(\fBfloat\fR \fIx\fR, \fBfloat\fR \fIy\fR, \fBint *\fR\fIquo\fR);
+.fi
+
+.LP
+.nf
+\fBlong double\fR \fBremquol\fR(\fBlong double\fR \fIx\fR, \fBlong double\fR \fIy\fR, \fBint *\fR\fIquo\fR);
+.fi
+
+.SH DESCRIPTION
+.sp
+.LP
+The \fBremquo()\fR, \fBremquof()\fR, and \fBremquol()\fR functions compute the
+same remainder as the \fBremainder()\fR, \fBremainderf()\fR, and
+\fBremainderl()\fR functions, respectively. See \fBremainder\fR(3M). In the
+object pointed to by \fIquo\fR, they store a value whose sign is the sign of
+\fIx\fR/\fIy\fR and whose magnitude is congruent modulo 2^\fIn\fR to the
+magnitude of the integral quotient of \fIx\fR/\fIy\fR, where \fIn\fR is an
+integer greater than or equal to 3.
+.SH RETURN VALUES
+.sp
+.LP
+These functions return \fIx\fR REM \fIy\fR.
+.sp
+.LP
+If \fIx\fR or \fIy\fR is NaN, a NaN is returned.
+.sp
+.LP
+If \fIx\fR is \(+-Inf or \fIy\fR is 0 and the other argument is non-NaN, a
+domain error occurs and a NaN is returned.
+.SH ERRORS
+.sp
+.LP
+These functions will fail if:
+.sp
+.ne 2
+.mk
+.na
+\fBDomain Error\fR
+.ad
+.RS 16n
+.rt  
+The \fIx\fR argument is Inf or the \fIy\fR argument is 0 and the other argument
+is non-NaN.
+.sp
+If the integer expression (\fBmath_errhandling\fR & \fBMATH_ERREXCEPT\fR) is
+non-zero, then the invalid floating-point exception is raised.
+.RE
+
+.SH USAGE
+.sp
+.LP
+An application wanting to check for exceptions should call
+\fBfeclearexcept\fR(\fBFE_ALL_EXCEPT\fR) before calling these functions. On
+return, if \fBfetestexcept\fR(\fBFE_INVALID\fR | \fBFE_DIVBYZERO\fR |
+\fBFE_OVERFLOW\fR | \fBFE_UNDERFLOW\fR) is non-zero, an exception has been
+raised. An application should either examine the return value or check the
+floating point exception flags to detect exceptions.
+.SH ATTRIBUTES
+.sp
+.LP
+See \fBattributes\fR(5) for descriptions of the following attributes:
+.sp
+
+.sp
+.TS
+tab() box;
+cw(2.75i) |cw(2.75i) 
+lw(2.75i) |lw(2.75i) 
+.
+ATTRIBUTE TYPEATTRIBUTE VALUE
+_
+Interface StabilityStandard
+_
+MT-LevelMT-Safe
+.TE
+
+.SH SEE ALSO
+.sp
+.LP
+\fBfeclearexcept\fR(3M), \fBfetestexcept\fR(3M), \fBmath.h\fR(3HEAD),
+\fBremainder\fR(3M), \fBattributes\fR(5), \fBstandards\fR(5)
